==> texinfo-6.6.tar.gz: texinfo-6.6/tp/t/results/formatting/simplest_test_prefix.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text);

use utf8;

$result_trees{'simplest_test_prefix'} = {
  'contents' => [
    {
      'contents' => [
        {
          'contents' => [
            {
              'contents' => [
                {
                  'parent' => {},
                  'text' => '\\input texinfo @c -*-texinfo-*-
',
                  'type' => 'preamble_text'
                },
                {
                  'parent' => {},
                  'text' => '
',
                  'type' => 'preamble_text'
                }
              ],
              'parent' => {},
              'type' => 'preamble'
            }
          ],
          'parent' => {},
          'type' => 'preamble_before_setfilename'
        },
        {
          'args' => [
            {
              'contents' => [
                {
                  'parent' => {},
                  'text' => 'simplest.info'
                }
              ],
              'extra' => {
                'spaces_after_argument' => '
'
              },
              'parent' => {},
              'type' => 'line_arg'
            }
          ],
          'cmdname' => 'setfilename',
          'extra' => {
            'spaces_before_argument' => ' ',
            'text_arg' => 'simplest.info'
          },
          'line_nr' => {
            'file_name' => 'simplest.texi',
            'line_nr' => 3,
            'macro' => ''
          },
          'parent' => {}
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'parent' => {},
      'type' => 'text_root'
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'Top'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'node',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'This is a very simple texi manual '
            },
            {
              'cmdname' => ' ',
              'parent' => {}
            },
            {
              'parent' => {},
              'text' => ' <>.
'
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'node_content' => [
          {}
        ],
        'nodes_manuals' => [
          {
            'node_content' => [],
            'normalized' => 'Top'
          }
        ],
        'normalized' => 'Top',
        'spaces_before_argument' => ' '
      },
      'line_nr' => {
        'file_name' => 'simplest.texi',
        'line_nr' => 5,
        'macro' => ''
      },
      'parent' => {}
    },
    {
      'args' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'misc_arg'
        }
      ],
      'cmdname' => 'bye',
      'parent' => {}
    }
  ],
  'type' => 'document_root'
};
$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[0];
$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0];
$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1]{'args'}[0];
$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1];
$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0];
$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0];
$result_trees{'simplest_test_prefix'}{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'};
$result_trees{'simplest_test_prefix'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[1]{'args'}[0];
$result_trees{'simplest_test_prefix'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[1];
$result_trees{'simplest_test_prefix'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[1];
$result_trees{'simplest_test_prefix'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[1]{'contents'}[1];
$result_trees{'simplest_test_prefix'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[1]{'contents'}[1];
$result_trees{'simplest_test_prefix'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[1]{'contents'}[1];
$result_trees{'simplest_test_prefix'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[1];
$result_trees{'simplest_test_prefix'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[1];
$result_trees{'simplest_test_prefix'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'simplest_test_prefix'}{'contents'}[1]{'args'}[0]{'contents'}[0];
$result_trees{'simplest_test_prefix'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'simplest_test_prefix'}{'contents'}[1]{'extra'}{'node_content'};
$result_trees{'simplest_test_prefix'}{'contents'}[1]{'parent'} = $result_trees{'simplest_test_prefix'};
$result_trees{'simplest_test_prefix'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[2];
$result_trees{'simplest_test_prefix'}{'contents'}[2]{'parent'} = $result_trees{'simplest_test_prefix'};

$result_texis{'simplest_test_prefix'} = '\\input texinfo @c -*-texinfo-*-

@setfilename simplest.info

@node Top

This is a very simple texi manual @  <>.

@bye
';


$result_texts{'simplest_test_prefix'} = '

This is a very simple texi manual   <>.

';

$result_sectioning{'simplest_test_prefix'} = {};

$result_nodes{'simplest_test_prefix'} = {
  'cmdname' => 'node',
  'extra' => {
    'normalized' => 'Top',
    'spaces_before_argument' => ' '
  },
  'node_up' => {
    'extra' => {
      'manual_content' => [
        {
          'text' => 'dir'
        }
      ],
      'top_node_up' => {}
    },
    'type' => 'top_node_up'
  }
};
$result_nodes{'simplest_test_prefix'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'simplest_test_prefix'};

$result_menus{'simplest_test_prefix'} = {
  'cmdname' => 'node',
  'extra' => {
    'normalized' => 'Top',
    'spaces_before_argument' => ' '
  }
};

$result_errors{'simplest_test_prefix'} = [];


$result_converted_errors{'file_html'}->{'simplest_test_prefix'} = [
  {
    'error_line' => 'simplest.texi: warning: must specify a title with a title command or @top
',
    'text' => 'must specify a title with a title command or @top',
    'type' => 'warning'
  }
];


1;

==> texinfo-7.0.1.tar.gz: texinfo-7.0.1/tp/t/results/formatting/simplest_test_prefix.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'simplest_test_prefix'} = {
  'contents' => [
    {
      'contents' => [
        {
          'contents' => [
            {
              'contents' => [
                {
                  'text' => '\\input texinfo @c -*-texinfo-*-
',
                  'type' => 'text_before_beginning'
                },
                {
                  'text' => '
',
                  'type' => 'text_before_beginning'
                }
              ],
              'type' => 'preamble_before_beginning'
            }
          ],
          'type' => 'preamble_before_setfilename'
        },
        {
          'contents' => [
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'text' => 'simplest.info'
                    }
                  ],
                  'extra' => {
                    'spaces_after_argument' => '
'
                  },
                  'type' => 'line_arg'
                }
              ],
              'cmdname' => 'setfilename',
              'extra' => {
                'spaces_before_argument' => ' ',
                'text_arg' => 'simplest.info'
              },
              'source_info' => {
                'file_name' => 'simplest.texi',
                'line_nr' => 3,
                'macro' => ''
              }
            },
            {
              'text' => '
',
              'type' => 'empty_line'
            }
          ],
          'type' => 'preamble_before_content'
        }
      ],
      'type' => 'before_node_section'
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'text' => 'Top'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'node',
      'contents' => [
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'text' => 'This is a very simple texi manual '
            },
            {
              'cmdname' => ' '
            },
            {
              'text' => ' <>.
'
            }
          ],
          'type' => 'paragraph'
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'extra' => {
        'node_content' => [
          {}
        ],
        'nodes_manuals' => [
          {
            'node_content' => [
              {}
            ],
            'normalized' => 'Top'
          }
        ],
        'normalized' => 'Top',
        'spaces_before_argument' => ' '
      },
      'source_info' => {
        'file_name' => 'simplest.texi',
        'line_nr' => 5,
        'macro' => ''
      }
    },
    {
      'args' => [
        {
          'text' => '
',
          'type' => 'misc_arg'
        }
      ],
      'cmdname' => 'bye'
    }
  ],
  'type' => 'document_root'
};
$result_trees{'simplest_test_prefix'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'simplest_test_prefix'}{'contents'}[1]{'args'}[0]{'contents'}[0];
$result_trees{'simplest_test_prefix'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'simplest_test_prefix'}{'contents'}[1]{'args'}[0]{'contents'}[0];

$result_texis{'simplest_test_prefix'} = '\\input texinfo @c -*-texinfo-*-

@setfilename simplest.info

@node Top

This is a very simple texi manual @  <>.

@bye
';


$result_texts{'simplest_test_prefix'} = '

This is a very simple texi manual   <>.

';

$result_nodes{'simplest_test_prefix'} = {
  'cmdname' => 'node',
  'extra' => {
    'normalized' => 'Top'
  }
};

$result_menus{'simplest_test_prefix'} = {
  'cmdname' => 'node',
  'extra' => {
    'normalized' => 'Top'
  }
};

$result_errors{'simplest_test_prefix'} = [];


$result_floats{'simplest_test_prefix'} = {};


$result_converted_errors{'file_html'}->{'simplest_test_prefix'} = [
  {
    'error_line' => 'warning: must specify a title with a title command or @top
',
    'file_name' => 'simplest.texi',
    'text' => 'must specify a title with a title command or @top',
    'type' => 'warning'
  }
];


1;
